# ---------------------------------------------------------------------------
# pydio/_compat.py
#
# Copyright (C) 2021 - 2022 Maciej Wiatrzyk <maciej.wiatrzyk@gmail.com>
#
# This file is part of PyDio library and is released under the terms of the
# MIT license: http://opensource.org/licenses/mit-license.php.
#
# See LICENSE.txt for details.
# ---------------------------------------------------------------------------
from contextlib import AbstractAsyncContextManager

__all__ = ['AbstractAsyncContextManager']
